#
# spec file for package razor-agents
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_name Razor2-Client-Agent
Name:           razor-agents
Version:        2.86
Release:        1.11
Summary:        SPAM catalogue inquiry and update tool
License:        Artistic-2.0
Group:          Productivity/Networking/Email/Utilities
URL:            http://razor.sourceforge.net/
Source:         https://github.com/toddr/%{src_name}/archive/refs/tags/v%{version}.tar.gz#/%{src_name}-%{version}.tar.gz
Source1:        README.SUSE
Requires:       perl-razor-agents
%{perl_requires}

%description
Vipul's Razor is a distributed, collaborative, spam detection and
filtering network. Razor establishes a distributed and constantly
updating catalogue of spam in propagation. This catalogue is used by
clients to filter out known spam. On receiving a spam, a Razor
Reporting Agent (run by an end-user or a troll box) calculates and
submits a 20-character unique identification of the spam (a SHA Digest)
to its closest Razor Catalogue Server. The Catalogue Server echos this
signature to other trusted servers after storing it in its database.
Prior to manual processing or transport-level reception, Razor
Filtering Agents (end-users and MTAs) check their incoming mail against
a Catalogue Server and filter out or deny transport in case of a
signature match. Catalogued spam, once identified and reported by a
Reporting Agent, can be blocked out by the rest of the Filtering Agents
on the network.

Can be used as one of the spamassassin rules.

%package -n perl-razor-agents
Summary:        The required perl modules for razor-agents
License:        Artistic-1.0
Group:          Development/Languages/Perl
Requires:       perl-Digest-SHA1
Requires:       perl-URI

%description -n perl-razor-agents
razor-agents are little programs to retrieve or update information
from the razor <http://razor.sourceforge.net/> network to exchange
signatures of SPAM. This package contains the required perl modules.

%prep
%setup -q -n %{src_name}-%{version}
cp %{SOURCE1} .

%build
perl Makefile.PL OPTIMIZE="%{optflags} -Wall"
make

%check
make test

%install
make DESTDIR=%{buildroot} INSTALLMAN5DIR=%{buildroot}/%{_mandir}/man5 install_vendor
%perl_process_packlist

%files -n perl-razor-agents
%doc BUGS CREDITS Changes FAQ README.SUSE
%license LICENSE
%{_mandir}/man3/Razor*
%{_mandir}/man5/razor*
%{perl_vendorarch}/Razor2
%{perl_vendorarch}/auto/Razor2

%files
%{_mandir}/man1/razor*
%{_bindir}/razor*

%changelog
* Sun May 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.86
  * Switch to modern XSLoader
- Used spec-cleaner to modernize the SPEC file
- Dropped fixed razor-agents-perl522.patch
* Thu Jun 11 2015 hsk@imb-jena.de
- razor-agents-perl522.patch: fix razor man page installation with
  perl-5.22
- updated .spec file: "Require" only module packages actually used by
  razor-agents-2.85
* Tue Aug 13 2013 ncutler@suse.com
- Relicense under Artistic License 2.0.  See LICENSE for details.
- got rid of INSTALL, replaced with README.SUSE
* Fri Jul 26 2013 tchvatal@suse.com
- perl-macros is obsoleted by recent perl packages.
  Therefore BuildRequire perl-macros only on older versions
  (which includes SLE)
* Sun Aug 28 2011 andrea.turrini@gmail.com
- fixed typo in razor-agents.spec (perl-razor-agents)
* Sun Apr 10 2011 varkoly@novell.com
- bnc#675925 - Fix license declaration of razor-agents
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Feb 10 2008 varkoly@suse.de
- Marking the man files as %%doc files so they can left out using --excludedocs during installation.
- Update to version 2.48
  * Update discovery hostname
  * Remove all uses of $' from code. This removes a global regex engine slowdown.
  * Comment out or replace shell commands with Perl equivalents.
  * Always disconnect from discovery server after performing discovery.
  * When registering with a username and password, accept existing credentials if they authenticate successfully.
  * Ensure that checks and reports are sent to the appropriate servers.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov  4 2005 choeger@suse.de
- Update to razor-agents-2.77
* Tue Jun 21 2005 choeger@suse.de
- Update to razor-agents-2.72
* Wed Jan 12 2005 choeger@suse.de
- Update to razor-agents-2.67
* Tue Aug 17 2004 ro@suse.de
- perl-Digest-Nilsimsa really removed from requires
* Mon Aug 16 2004 garloff@suse.de
- Really fix manpage (5) installation ;-)
- Update to razor-agents-2.61:
  * Whiplash signatures
  * MIME parser bugfix
  * Engine 1 signature not supported any more
- Update to razor-agents-2.40:
  * Fix manpage (5) installation
  * Untaint patch integrated (Razor2.patch, #32719)
  * http1.1 tunnelling
  * perl-Digest-Nilsimsa no longer required by razor
* Sun Mar 21 2004 ro@suse.de
- remove .orig backup files
* Tue Dec  9 2003 ro@suse.de
- removed perl-Net-Ping from requires (is in perl bundle)
* Tue Dec  2 2003 garloff@suse.de
- Add missing dependencies on perl modules.
* Thu Oct 30 2003 choeger@suse.de
- updated to 2.36
- added Razor2.patch to solve Bugzilla ID#32719,
  spamassassin skips razor checks
  see http://spamassassin.taint.org/faq/index.cgi?req=show&file=faq02.006.htp
  for more details
- added norootforbuild
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 31 2003 ro@suse.de
- remove man5 hacks from Makefile.PL and create manually
* Mon Jul 28 2003 coolo@suse.de
- fix file list
* Mon Jul 14 2003 garloff@suse.de
- Patch Makefile that the perl Makefile.PL produces. Ugly :-(
* Mon Jul 14 2003 garloff@suse.de
- Install to %%perl_vendorarch, use %%perl_process_packlist.
- Update to razor-agents-2.34:
  * razor-check handles messages gracefully now, when no signature
    can be computed
  * no server sorting by distance any more
  * string splitting fix
  * getpwuid() to determine user's home dir
  * fallback to /etc/razor is no razor home can be found
  * error messages improved
  * server discovery process improved
* Mon Jun 23 2003 ro@suse.de
- added directories to filelist
* Wed Apr  2 2003 garloff@suse.de
- Add missing symlinks
* Mon Mar 31 2003 garloff@suse.de
- Fix file list
* Sun Mar 30 2003 garloff@suse.de
- Update to version 2.22:
  * Better whitespace handling
  * Minor speedups (deHTML)
* Mon Oct  7 2002 garloff@suse.de
- Add dependency on perl-URI. [Bug #20548]
* Fri Aug  9 2002 mls@suse.de
- use sitearch macro
* Fri Aug  2 2002 garloff@suse.de
- Updated to version 2.126:
  * Less runtime warnings
  * Bugfix WRT revoke/report
  * Whitelist check looks at all Received: headers now
  * Improved logic for spam detection
* Thu Aug  1 2002 ro@suse.de
- fixed man5 installation
* Mon Jul 29 2002 mls@suse.de
- fixed neededforbuild for perl-5.8.0
* Wed Jul 17 2002 garloff@suse.de
- Update to version 2.122: Many improvements and new features.
  Check http://razor.sourceforge.net/docs/whatsnew.html
* Thu May  9 2002 garloff@suse.de
- Build package razor-agents-1.20
- Split into razor-agents and perl-razor-agents
- Fix installation of razor.conf(5) and razor-whitelist(5)
  manpages
- Provide sample razor.conf
